==> kbibtex-0.1.1.tar.bz2: kbibtex-0.1.1/src/kbibtexsettingsediting.cpp <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#include <qlayout.h>
#include <qlabel.h>
#include <qcombobox.h>
#include <qgroupbox.h>
#include <qcheckbox.h>
#include <klocale.h>
#include <kdialog.h>

#include <kbibtexlistview.h>

#include "settings.h"
#include "kbibtexsettingsediting.h"

KBibTeXSettingsEditing::KBibTeXSettingsEditing( QWidget *parent, const char *name )
        : QWidget( parent, name )
{
    QGroupBox * group = NULL;
    QVBoxLayout *layout = new QVBoxLayout( this, 0, KDialog::spacingHint() );

    group = new QGroupBox( 2, Qt::Vertical, i18n( "Main List" ), this );
    layout->addWidget( group );
    QLabel *label = new QLabel( i18n( "&Sorting:" ), group );
    m_comboBoxColumnHeaders = new QComboBox( FALSE, group );
    m_comboBoxColumnHeaders->insertItem( i18n( "No sorting" ) );
    for ( int i = 0; i < ColumnsCount;i++ )
        m_comboBoxColumnHeaders->insertItem( Columns[ i ] );
    label->setBuddy( m_comboBoxColumnHeaders );

    group = new QGroupBox( 1, Qt::Vertical, i18n( "Entry Editing" ), this );
    layout->addWidget( group );
    m_checkBoxEnableAllFields = new QCheckBox( i18n( "Enable all &fields for editing" ), group );

    layout->addStretch();

    connect( m_checkBoxEnableAllFields, SIGNAL( toggled( bool ) ), this, SLOT( slotConfigChanged() ) );
}


KBibTeXSettingsEditing::~KBibTeXSettingsEditing()
{
    //TODO
}

void KBibTeXSettingsEditing::applyData()
{
    kbibtexsettings.enableallfields = m_checkBoxEnableAllFields->isChecked();
    kbibtexsettings.sortingColumn = m_comboBoxColumnHeaders->currentItem() - 1;
}

void KBibTeXSettingsEditing::setData()
{
    m_checkBoxEnableAllFields->setChecked( kbibtexsettings.enableallfields );
    m_comboBoxColumnHeaders->setCurrentItem( kbibtexsettings.sortingColumn + 1 );
}

void KBibTeXSettingsEditing::slotConfigChanged()
{
    emit configChanged();
}

#include "kbibtexsettingsediting.moc"

==> kbibtex-0.1.2.tar.bz2: kbibtex-0.1.2/src/kbibtexsettingsediting.cpp <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#include <qlayout.h>
#include <qlabel.h>
#include <qcombobox.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qgroupbox.h>
#include <qpushbutton.h>
#include <qcheckbox.h>
#include <klocale.h>
#include <kdialog.h>

#include <kbibtexlistview.h>

#include "settings.h"
#include "kbibtexsettingsediting.h"

KBibTeXSettingsEditing::KBibTeXSettingsEditing( QWidget *parent, const char *name )
        : QWidget( parent, name )
{
    QGroupBox * group = NULL;
    QVBoxLayout *layout = new QVBoxLayout( this, 0, KDialog::spacingHint() );

    group = new QGroupBox( 2, Qt::Vertical, i18n( "Main List" ), this );
    layout->addWidget( group );
    QLabel *label = new QLabel( i18n( "&Sorting:" ), group );
    m_comboBoxColumnHeaders = new QComboBox( FALSE, group );
    m_comboBoxColumnHeaders->insertItem( i18n( "No sorting" ) );
    for ( int i = 0; i < ColumnsCount;i++ )
        m_comboBoxColumnHeaders->insertItem( Columns[ i ] );
    label->setBuddy( m_comboBoxColumnHeaders );

    group = new QGroupBox( 1, Qt::Vertical, i18n( "Entry Editing" ), this );
    layout->addWidget( group );
    m_checkBoxEnableAllFields = new QCheckBox( i18n( "Enable all &fields for editing" ), group );

    layout->addStretch();

    connect( m_checkBoxEnableAllFields, SIGNAL( toggled( bool ) ), this, SLOT( slotConfigChanged() ) );
}


KBibTeXSettingsEditing::~KBibTeXSettingsEditing()
{
    //TODO
}

void KBibTeXSettingsEditing::applyData()
{
    kbibtexsettings.enableallfields = m_checkBoxEnableAllFields->isChecked();
    kbibtexsettings.mainListSortingColumn = m_comboBoxColumnHeaders->currentItem() - 1;
}

void KBibTeXSettingsEditing::setData()
{
    m_checkBoxEnableAllFields->setChecked( kbibtexsettings.enableallfields );
    m_comboBoxColumnHeaders->setCurrentItem( kbibtexsettings.mainListSortingColumn + 1 );
}

void KBibTeXSettingsEditing::slotConfigChanged()
{
    emit configChanged();
}

#include "kbibtexsettingsediting.moc"
